///File : DialogAbout.cpp
//------------------------------------------------------------------------------
/*
    This file is part of LCDnurse.

    LCDnurse is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    LCDnurse is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with LCDnurse.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "DialogAbout.hpp"
//------------------------------------------------------------------------------

DialogAbout::DialogAbout( wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style ) : wxDialog( parent, id, title, pos, size, style )
{
    // Icon
    SetIcon(static_cast<wxTopLevelWindow*>(GetParent())->GetIcon());

	this->SetSizeHints( wxDefaultSize, wxDefaultSize );

	wxBoxSizer* sizerAll = new wxBoxSizer( wxVERTICAL );
	wxBoxSizer* sizerImg = new wxBoxSizer( wxHORIZONTAL );

    wxString ImgFileName = findFile(_T("data/lcdnurse-icon.png"));
    if(wxFileExists(ImgFileName))
    {
        wxImage img(ImgFileName, wxBITMAP_TYPE_PNG);
        m_bitmapIcone = new wxStaticBitmap( this, wxID_ANY, wxBitmap(img), wxDefaultPosition, wxSize(48,48));
        sizerImg->Add( m_bitmapIcone, 0, wxALL, 5 );
    }

	wxBoxSizer* sizerTxt;
	sizerTxt = new wxBoxSizer( wxVERTICAL );

	m_staticTextTitre = new wxStaticText( this, wxID_ANY, _T("LCD Nurse"));
	m_staticTextTitre->SetFont( wxFont( 16, 74, 90, 92, false, wxT("Sans")));
	m_staticTextTitre->SetForegroundColour( wxColour( 0, 60, 118 ) );
	sizerTxt->Add( m_staticTextTitre, 0, wxEXPAND|wxLEFT|wxRIGHT|wxTOP, 5 );

	m_staticTextVersion = new wxStaticText( this, wxID_ANY, wxString::Format(_("Version %s"), NUM_VERSION));
	m_staticTextVersion->SetFont( wxFont( 10, 74, 90, 92, false, wxT("Sans") ) );
	m_staticTextVersion->SetForegroundColour( wxColour( 69, 141, 196 ) );
	sizerTxt->Add( m_staticTextVersion, 0, wxLEFT, 50 );
	sizerImg->Add( sizerTxt, 0, 0, 5 );
	sizerAll->Add( sizerImg, 0, wxEXPAND, 5 );

	m_NotebookAutorLicence = new wxNotebook( this, wxID_ANY);

	MyPanelNoteBookAutors = new PanelNoteBookAutors(m_NotebookAutorLicence);
	m_NotebookAutorLicence->AddPage(MyPanelNoteBookAutors, _("Autors"), true);

	wxTextCtrl *LicenceTxt = new wxTextCtrl(m_NotebookAutorLicence, wxID_ANY,_(
	"This file is part of LCDnurse.\n"
    "\n"
    "LCDnurse is free software: you can redistribute it and/or modify\n"
    "it under the terms of the GNU General Public License as published by\n"
    "the Free Software Foundation, either version 3 of the License, or\n"
    "(at your option) any later version.\n"
    "\n"
    "LCDnurse is distributed in the hope that it will be useful,\n"
    "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
    "GNU General Public License for more details.\n"
    "\n"
    "You should have received a copy of the GNU General Public License\n"
    "along with LCDnurse.  If not, see <http://www.gnu.org/licenses/>."), wxDefaultPosition, wxDefaultSize, wxTE_MULTILINE | wxTE_READONLY);

	m_NotebookAutorLicence->AddPage(LicenceTxt, _("Licence"), false);

	sizerAll->Add( m_NotebookAutorLicence, 1, wxEXPAND | wxALL, 5 );

	m_BtOk = new wxButton(this, wxID_OK);
	sizerAll->Add( m_BtOk, 0, wxALIGN_RIGHT | wxBOTTOM | wxRIGHT, 5 );
	m_BtOk->SetFocus();

	this->SetSizer( sizerAll );
	this->Layout();
}

//------------------------------------------------------------------------------
PanelNoteBookAutors::PanelNoteBookAutors( wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style ) : wxPanel( parent, id, pos, size, style )
{
	wxBoxSizer *sizerNoteBookAutors = new wxBoxSizer( wxVERTICAL );

	m_AuteurStaticText = new wxStaticText(this, wxID_ANY, _T("Colin GILLE / Congelli501"));
	sizerNoteBookAutors->Add(m_AuteurStaticText);

    wxString ImgFileName = findFile(_T("data/c501-logo.png"));
    if(wxFileExists(ImgFileName))
    {
        wxImage img(ImgFileName, wxBITMAP_TYPE_PNG);
        m_ImgLogoC501 = new wxStaticBitmap( this, wxID_ANY, wxBitmap(img));
        sizerNoteBookAutors->Add( m_ImgLogoC501);
    }

	this->SetSizer(sizerNoteBookAutors);
}
